@@ -91,7 +91,7 @@
 #'predictor can contain any of `mvgam`'s allowed predictor effects, providing enormous flexibility for
 #'modelling species' communities.
 #'@seealso [mvgam()], [residual_cor()]
-#'@references Nicholas J Clark & Konstans Wells (2020). Dynamic generalised additive models (DGAMs) for forecasting discrete ecological time series.
+#'@references Nicholas J Clark & Konstans Wells (2023). Dynamic generalised additive models (DGAMs) for forecasting discrete ecological time series.
 #'Methods in Ecology and Evolution. 14:3, 771-784.
 #' \cr
 #' \cr
@@ -190,7 +190,7 @@
 #'   dplyr::group_by(lat, lon) -> dat
 #'
 #' # View the count distributions for each species
-#' library(ggplot2)
+#' library(ggplot2); theme_set(theme_bw())
 #' ggplot(dat, aes(x = count)) +
 #'   geom_histogram() +
 #'   facet_wrap(~ species, scales = 'free')
@@ -198,8 +198,7 @@
 #' ggplot(dat, aes(x = lon, y = lat, col = log(count + 1))) +
 #'   geom_point(size = 2.25) +
 #'   facet_wrap(~ species, scales = 'free') +
-#'   scale_color_viridis_c() +
-#'   theme_classic()
+#'   scale_color_viridis_c()
 #'
 #' # Inspect default priors for a joint species model with three spatial factors
 #' priors <- get_mvgam_priors(formula = count ~
@@ -267,9 +266,17 @@
 #'
 #' # Or using gratia, if you have it installed
 #' if(requireNamespace('gratia', quietly = TRUE)){
-#'   gratia::draw(mod, trend_effects = TRUE)
+#'   gratia::draw(mod, trend_effects = TRUE, dist = 0)
 #' }
 #'
+#' # Plot species' randomized quantile residual distributions
+#' # as a function of latitude
+#' pp_check(mod,
+#'          type = 'resid_ribbon_grouped',
+#'          group = 'species',
+#'          x = 'lat',
+#'          ndraws = 200)
+#'
 #' # Calculate residual spatial correlations
 #' post_cors <- residual_cor(mod)
 #' names(post_cors)
@@ -280,12 +287,15 @@
 #' post_cors$cor_upper[1:5, 1:5]
 #' post_cors$cor_lower[1:5, 1:5]
 
-#' # A quick and dirty plot of the posterior median correlations
-#' image(post_cors$cor)
+#' # Plot of the posterior median correlations for those estimated
+#' # to be non-zero
+#' plot(post_cors)
 #'
 #' # Posterior predictive checks and ELPD-LOO can ascertain model fit
-#' pp_check(mod, type = "pit_ecdf_grouped",
-#'          group = "species", ndraws = 100)
+#' pp_check(mod,
+#'          type = "pit_ecdf_grouped",
+#'          group = "species",
+#'          ndraws = 200)
 #' loo(mod)
 #'
 #' # Forecast log(counts) for entire region (site value doesn't matter as long
@@ -310,33 +320,34 @@
 #'   theme_classic()
 #'}
 #'@export
-jsdgam = function(formula,
-                  factor_formula = ~ -1,
-                  knots,
-                  factor_knots,
-                  data,
-                  newdata,
-                  family = poisson(),
-                  unit = time,
-                  species = series,
-                  share_obs_params = FALSE,
-                  priors,
-                  n_lv = 2,
-                  backend = getOption("brms.backend", "cmdstanr"),
-                  algorithm = getOption("brms.algorithm", "sampling"),
-                  control = list(max_treedepth = 10,
-                                 adapt_delta = 0.8),
-                  chains = 4,
-                  burnin = 500,
-                  samples = 500,
-                  thin = 1,
-                  parallel = TRUE,
-                  threads = 1,
-                  silent = 1,
-                  run_model = TRUE,
-                  return_model_data = FALSE,
-                  ...){
-
+jsdgam = function(
+  formula,
+  factor_formula = ~ -1,
+  knots,
+  factor_knots,
+  data,
+  newdata,
+  family = poisson(),
+  unit = time,
+  species = series,
+  share_obs_params = FALSE,
+  priors,
+  n_lv = 2,
+  backend = getOption("brms.backend", "cmdstanr"),
+  algorithm = getOption("brms.algorithm", "sampling"),
+  control = list(max_treedepth = 10, adapt_delta = 0.8),
+  chains = 4,
+  burnin = 500,
+  samples = 500,
+  thin = 1,
+  parallel = TRUE,
+  threads = 1,
+  silent = 1,
+  run_model = TRUE,
+  return_model_data = FALSE,
+  residuals = TRUE,
+  ...
+) {
   #### Validate arguments and initialise the model skeleton ####
   validate_pos_integer(n_lv)
 
@@ -344,11 +355,8 @@ jsdgam = function(formula,
   # mvgam fashion (with 'time' and 'series' variables)
   unit <- deparse0(substitute(unit))
   subgr <- deparse0(substitute(species))
-  prepped_trend <- prep_jsdgam_trend(unit = unit,
-                                     subgr = subgr,
-                                     data = data)
-  data_train <- validate_series_time(data = data,
-                                     trend_model = prepped_trend)
+  prepped_trend <- prep_jsdgam_trend(unit = unit, subgr = subgr, data = data)
+  data_train <- validate_series_time(data = data, trend_model = prepped_trend)
 
   # Set up a simple trend_map to get the model dimensions correct;
   # this requires that we only have n_lv trends and that each series
@@ -358,115 +366,158 @@ jsdgam = function(formula,
 
   # Set up the model structure but leave autoformat off so that the
   # model file can be easily modified
-  mod <- mvgam(formula = formula,
-               trend_formula = factor_formula,
-               knots = knots,
-               trend_knots = factor_knots,
-               family = family,
-               share_obs_params = share_obs_params,
-               priors = priors,
-               trend_model = 'None',
-               trend_map = trend_map,
-               data = data_train,
-               noncentred = TRUE,
-               run_model = FALSE,
-               autoformat = FALSE,
-               backend = backend,
-               ...)
+  mod <- mvgam(
+    formula = formula,
+    trend_formula = factor_formula,
+    knots = knots,
+    trend_knots = factor_knots,
+    family = family,
+    share_obs_params = share_obs_params,
+    priors = priors,
+    trend_model = 'None',
+    trend_map = trend_map,
+    data = data_train,
+    noncentred = TRUE,
+    run_model = FALSE,
+    autoformat = FALSE,
+    backend = backend,
+    ...
+  )
   model_file <- mod$model_file
 
   #### Modify model data and model file ####
   # Remove Z from supplied data
-  model_file <- model_file[-grep("matrix[n_series, n_lv] Z; // matrix mapping series to latent states",
-                                 model_file, fixed = TRUE)]
+  model_file <- model_file[
+    -grep(
+      "matrix[n_series, n_lv] Z; // matrix mapping series to latent states",
+      model_file,
+      fixed = TRUE
+    )
+  ]
 
   # Add M to data block
-  model_file[grep('int<lower=0> n_lv; // number of dynamic factors',
-                  model_file, fixed = TRUE)] <- paste0(
-                    'int<lower=0> n_lv; // number of dynamic factors\n',
-                    'int<lower=0> M; // number of nonzero lower-triangular factor loadings'
-                  )
+  model_file[grep(
+    'int<lower=0> n_lv; // number of dynamic factors',
+    model_file,
+    fixed = TRUE
+  )] <- paste0(
+    'int<lower=0> n_lv; // number of dynamic factors\n',
+    'int<lower=0> M; // number of nonzero lower-triangular factor loadings'
+  )
   model_file <- readLines(textConnection(model_file), n = -1)
 
   # Update parameters
-  model_file <- model_file[-grep("// latent state SD terms",
-                                 model_file, fixed = TRUE)]
-  model_file <- model_file[-grep("vector<lower=0>[n_lv] sigma;",
-                                 model_file, fixed = TRUE)]
-  model_file[grep("matrix[n, n_lv] LV_raw;",
-                  model_file, fixed = TRUE)] <- paste0(
-                    "matrix[n, n_lv] LV_raw;\n\n",
-                    "// factor lower triangle loadings\n",
-                    "vector[M] L_lower;\n",
-                    "// factor diagonal loadings\n",
-                    "vector<lower=0>[n_lv] L_diag;")
+  model_file <- model_file[
+    -grep("// latent state SD terms", model_file, fixed = TRUE)
+  ]
+  model_file <- model_file[
+    -grep("vector<lower=0>[n_lv] sigma;", model_file, fixed = TRUE)
+  ]
+  model_file[grep(
+    "matrix[n, n_lv] LV_raw;",
+    model_file,
+    fixed = TRUE
+  )] <- paste0(
+    "matrix[n, n_lv] LV_raw;\n\n",
+    "// factor lower triangle loadings\n",
+    "vector[M] L_lower;\n",
+    "// factor diagonal loadings\n",
+    "vector<lower=0>[n_lv] L_diag;"
+  )
   model_file <- readLines(textConnection(model_file), n = -1)
 
   # Update transformed parameters
-  model_file <- model_file[-grep("// latent states",
-                                 model_file, fixed = TRUE)]
-  model_file <- model_file[-grep("lv_coefs = Z;",
-                                 model_file, fixed = TRUE)]
-  model_file <- model_file[-grep("matrix[n, n_lv] LV;",
-                                 model_file, fixed = TRUE)]
-  model_file <- model_file[-grep("trend_mus = X_trend * b_trend;",
-                                 model_file, fixed = TRUE)]
-  model_file[grep("matrix[n_series, n_lv] lv_coefs;",
-                  model_file, fixed = TRUE)] <- paste0(
-                    "matrix[n_series, n_lv] lv_coefs = rep_matrix(0, n_series, n_lv);\n",
-                    'matrix[n, n_lv] LV;\n')
+  model_file <- model_file[-grep("// latent states", model_file, fixed = TRUE)]
+  model_file <- model_file[-grep("lv_coefs = Z;", model_file, fixed = TRUE)]
+  model_file <- model_file[
+    -grep("matrix[n, n_lv] LV;", model_file, fixed = TRUE)
+  ]
+  model_file <- model_file[
+    -grep("trend_mus = X_trend * b_trend;", model_file, fixed = TRUE)
+  ]
+  model_file[grep(
+    "matrix[n_series, n_lv] lv_coefs;",
+    model_file,
+    fixed = TRUE
+  )] <- paste0(
+    "matrix[n_series, n_lv] lv_coefs = rep_matrix(0, n_series, n_lv);\n",
+    'matrix[n, n_lv] LV;\n'
+  )
 
-  starts <- grep("LV = LV_raw .* rep_matrix(sigma', rows(LV_raw));",
-                 model_file, fixed = TRUE)
+  starts <- grep(
+    "LV = LV_raw .* rep_matrix(sigma', rows(LV_raw));",
+    model_file,
+    fixed = TRUE
+  )
   ends <- starts + 5
   model_file <- model_file[-(starts:ends)]
-  model_file[grep("// latent process linear predictors",
-                  model_file, fixed = TRUE)] <- paste0(
-                    "// latent process linear predictors\n",
-                    "trend_mus = X_trend * b_trend;\n\n",
-                    "// constraints allow identifiability of loadings\n",
-                    "{\n",
-                    "int idx;\n",
-                    "idx = 0;\n",
-                    "for(j in 1 : n_lv) lv_coefs[j, j] = L_diag[j];\n",
-                    "for(j in 1 : n_lv) {\n",
-                    "for(k in (j + 1) : n_series) {\n",
-                    "idx = idx + 1;\n",
-                    "lv_coefs[k, j] = L_lower[idx];\n",
-                    "}\n",
-                    "}\n",
-                    "}\n\n",
-                    "// raw latent factors (with linear predictors)\n",
-                    "for (j in 1 : n_lv) {\n",
-                    "for (i in 1 : n) {\n",
-                    "LV[i, j] = trend_mus[ytimes_trend[i, j]] + LV_raw[i, j];\n",
-                    "}\n}\n")
+  model_file[grep(
+    "// latent process linear predictors",
+    model_file,
+    fixed = TRUE
+  )] <- paste0(
+    "// latent process linear predictors\n",
+    "trend_mus = X_trend * b_trend;\n\n",
+    "// constraints allow identifiability of loadings\n",
+    "{\n",
+    "int idx;\n",
+    "idx = 0;\n",
+    "for(j in 1 : n_lv) lv_coefs[j, j] = L_diag[j];\n",
+    "for(j in 1 : n_lv) {\n",
+    "for(k in (j + 1) : n_series) {\n",
+    "idx = idx + 1;\n",
+    "lv_coefs[k, j] = L_lower[idx];\n",
+    "}\n",
+    "}\n",
+    "}\n\n",
+    "// raw latent factors (with linear predictors)\n",
+    "for (j in 1 : n_lv) {\n",
+    "for (i in 1 : n) {\n",
+    "LV[i, j] = trend_mus[ytimes_trend[i, j]] + LV_raw[i, j];\n",
+    "}\n}\n"
+  )
 
-  model_file <- model_file[-grep("// derived latent states",
-                                 model_file, fixed = TRUE)]
+  model_file <- model_file[
+    -grep("// derived latent states", model_file, fixed = TRUE)
+  ]
   model_file <- readLines(textConnection(model_file), n = -1)
 
   # Update model block
-  sigma_prior <- grep("// priors for latent state SD parameters",
-                      model_file, fixed = TRUE) + 1
+  sigma_prior <- grep(
+    "// priors for latent state SD parameters",
+    model_file,
+    fixed = TRUE
+  ) +
+    1
   model_file <- model_file[-sigma_prior]
-  model_file[grep("// priors for latent state SD parameters",
-                  model_file, fixed = TRUE)] <- paste0(
-                    "// priors for factors and loading coefficients\n",
-                    "L_lower ~ student_t(3, 0, 1);\n",
-                    "L_diag ~ student_t(3, 0, 1);")
+  model_file[grep(
+    "// priors for latent state SD parameters",
+    model_file,
+    fixed = TRUE
+  )] <- paste0(
+    "// priors for factors and loading coefficients\n",
+    "L_lower ~ student_t(3, 0, 1);\n",
+    "L_diag ~ student_t(3, 0, 1);"
+  )
   model_file <- readLines(textConnection(model_file), n = -1)
 
   # Update generated quantities
-  model_file[grep('matrix[n, n_series] mus;',
-                  model_file,
-                  fixed = TRUE)] <- paste0(
-                    'matrix[n, n_series] mus;\n',
-                    'vector[n_lv] sigma;')
-  model_file[grep("penalty = 1.0 / (sigma .* sigma);",
-                  model_file, fixed = TRUE)] <- paste0(
-                    "penalty = rep_vector(1.0, n_lv);\n",
-                    "sigma = rep_vector(1.0, n_lv);")
+  model_file[grep(
+    'matrix[n, n_series] mus;',
+    model_file,
+    fixed = TRUE
+  )] <- paste0(
+    'matrix[n, n_series] mus;\n',
+    'vector[n_lv] sigma;'
+  )
+  model_file[grep(
+    "penalty = 1.0 / (sigma .* sigma);",
+    model_file,
+    fixed = TRUE
+  )] <- paste0(
+    "penalty = rep_vector(1.0, n_lv);\n",
+    "sigma = rep_vector(1.0, n_lv);"
+  )
   model_file <- readLines(textConnection(model_file), n = -1)
   model_file <- sanitise_modelfile(model_file)
 
@@ -479,33 +530,37 @@ jsdgam = function(formula,
   model_data$M <- n_lv * (n_series - n_lv) + n_lv * (n_lv - 1) / 2
 
   #### Autoformat the Stan code ####
-  if(requireNamespace('cmdstanr', quietly = TRUE) & backend == 'cmdstanr'){
-    if(requireNamespace('cmdstanr') &
-       cmdstanr::cmdstan_version() >= "2.29.0") {
-      model_file <- .autoformat(model_file,
-                                overwrite_file = FALSE,
-                                backend = 'cmdstanr',
-                                silent = silent >= 1L)
+  if (requireNamespace('cmdstanr', quietly = TRUE) & backend == 'cmdstanr') {
+    if (
+      requireNamespace('cmdstanr') &
+        cmdstanr::cmdstan_version() >= "2.29.0"
+    ) {
+      model_file <- .autoformat(
+        model_file,
+        overwrite_file = FALSE,
+        backend = 'cmdstanr',
+        silent = silent >= 1L
+      )
     }
-    model_file <- readLines(textConnection(model_file),
-                            n = -1)
+    model_file <- readLines(textConnection(model_file), n = -1)
   } else {
-    model_file <- .autoformat(model_file,
-                              overwrite_file = FALSE,
-                              backend = 'rstan',
-                              silent = silent >= 1L)
-    model_file <- readLines(textConnection(model_file),
-                            n = -1)
+    model_file <- .autoformat(
+      model_file,
+      overwrite_file = FALSE,
+      backend = 'rstan',
+      silent = silent >= 1L
+    )
+    model_file <- readLines(textConnection(model_file), n = -1)
   }
 
   # Remove lp__ from monitor params if VB is to be used
   param <- unique(c(mod$monitor_pars, 'Sigma', 'LV'))
-  if(algorithm %in% c('meanfield', 'fullrank', 'pathfinder', 'laplace')){
+  if (algorithm %in% c('meanfield', 'fullrank', 'pathfinder', 'laplace')) {
     param <- param[!param %in% 'lp__']
   }
 
   #### Determine what to return ####
-  if(!run_model){
+  if (!run_model) {
     mod$model_file <- model_file
     mod$monitor_pars <- param
     attr(model_data, 'trend_model') <- 'None'
@@ -516,61 +571,63 @@ jsdgam = function(formula,
     out <- mod
   } else {
     # Check if cmdstan is accessible; if not, use rstan
-    if(backend == 'cmdstanr'){
-      if(!requireNamespace('cmdstanr', quietly = TRUE)){
+    if (backend == 'cmdstanr') {
+      if (!requireNamespace('cmdstanr', quietly = TRUE)) {
         warning('cmdstanr library not found. Defaulting to rstan')
         use_cmdstan <- FALSE
       } else {
         use_cmdstan <- TRUE
-        if(is.null(cmdstanr::cmdstan_version(error_on_NA = FALSE))){
-          warning('cmdstanr library found but Cmdstan not found. Defaulting to rstan')
+        if (is.null(cmdstanr::cmdstan_version(error_on_NA = FALSE))) {
+          warning(
+            'cmdstanr library found but Cmdstan not found. Defaulting to rstan'
+          )
           use_cmdstan <- FALSE
         }
       }
     }
 
     #### Run the model ####
-    if(use_cmdstan){
-
+    if (use_cmdstan) {
       # Prepare threading and generate the model
-      cmd_mod <- .model_cmdstanr(model_file,
-                                 threads = threads,
-                                 silent = silent)
+      cmd_mod <- .model_cmdstanr(model_file, threads = threads, silent = silent)
 
       # Condition the model using Cmdstan
-      out_gam_mod <- .sample_model_cmdstanr(model = cmd_mod,
-                                            algorithm = algorithm,
-                                            prior_simulation = FALSE,
-                                            data = model_data,
-                                            chains = chains,
-                                            parallel = parallel,
-                                            silent = silent,
-                                            max_treedepth = control$max_treedepth,
-                                            adapt_delta = control$adapt_delta,
-                                            threads = threads,
-                                            burnin = burnin,
-                                            samples = samples,
-                                            param = param,
-                                            save_all_pars = FALSE,
-                                            ...)
-
+      out_gam_mod <- .sample_model_cmdstanr(
+        model = cmd_mod,
+        algorithm = algorithm,
+        prior_simulation = FALSE,
+        data = model_data,
+        chains = chains,
+        parallel = parallel,
+        silent = silent,
+        max_treedepth = control$max_treedepth,
+        adapt_delta = control$adapt_delta,
+        threads = threads,
+        burnin = burnin,
+        samples = samples,
+        param = param,
+        save_all_pars = FALSE,
+        ...
+      )
     } else {
       # Condition the model using rstan
       requireNamespace('rstan', quietly = TRUE)
-      out_gam_mod <- .sample_model_rstan(model = model_file,
-                                         algorithm = algorithm,
-                                         prior_simulation = FALSE,
-                                         data = model_data,
-                                         chains = chains,
-                                         parallel = parallel,
-                                         silent = silent,
-                                         max_treedepth = control$max_treedepth,
-                                         adapt_delta = control$adapt_delta,
-                                         threads = threads,
-                                         burnin = burnin,
-                                         samples = samples,
-                                         thin = thin,
-                                         ...)
+      out_gam_mod <- .sample_model_rstan(
+        model = model_file,
+        algorithm = algorithm,
+        prior_simulation = FALSE,
+        data = model_data,
+        chains = chains,
+        parallel = parallel,
+        silent = silent,
+        max_treedepth = control$max_treedepth,
+        adapt_delta = control$adapt_delta,
+        threads = threads,
+        burnin = burnin,
+        samples = samples,
+        thin = thin,
+        ...
+      )
     }
 
     # After modeling (add a new class to make predictions and other post-processing
@@ -578,29 +635,35 @@ jsdgam = function(formula,
     out1 <- mod
     out1$model_output <- out_gam_mod
     class(out1) <- c('mvgam')
-    mod_residuals <- dsresids_vec(out1)
+    if (residuals) {
+      mod_residuals <- dsresids_vec(out1)
+    } else {
+      mod_residuals <- NULL
+    }
     rm(out1)
 
     # Add the posterior median coefficients to the mgcv objects
     ss_gam <- mod$mgcv_model
     V <- cov(mcmc_chains(out_gam_mod, 'b'))
     ss_gam$Vp <- ss_gam$Vc <- V
-    p <- mcmc_summary(out_gam_mod, 'b',
-                      variational = algorithm %in% c('meanfield',
-                                                     'fullrank',
-                                                     'pathfinder',
-                                                     'laplace'))[,c(4)]
+    p <- mcmc_summary(
+      out_gam_mod,
+      'b',
+      variational = algorithm %in%
+        c('meanfield', 'fullrank', 'pathfinder', 'laplace')
+    )[, c(4)]
     names(p) <- names(ss_gam$coefficients)
     ss_gam$coefficients <- p
 
     trend_mgcv_model <- mod$trend_mgcv_model
     V <- cov(mcmc_chains(out_gam_mod, 'b_trend'))
     trend_mgcv_model$Vp <- trend_mgcv_model$Vc <- V
-    p <- mcmc_summary(out_gam_mod, 'b_trend',
-                      variational = algorithm %in% c('meanfield',
-                                                     'fullrank',
-                                                     'pathfinder',
-                                                     'laplace'))[,c(4)]
+    p <- mcmc_summary(
+      out_gam_mod,
+      'b_trend',
+      variational = algorithm %in%
+        c('meanfield', 'fullrank', 'pathfinder', 'laplace')
+    )[, c(4)]
     names(p) <- names(trend_mgcv_model$coefficients)
     trend_mgcv_model$coefficients <- p
 
@@ -613,58 +676,66 @@ jsdgam = function(formula,
 
     # Extract sampler arguments
     dots <- list(...)
-    if('adapt_delta' %in% names(dots)){
-      message('argument "adapt_delta" should be supplied as an element in "control"')
+    if ('adapt_delta' %in% names(dots)) {
+      message(
+        'argument "adapt_delta" should be supplied as an element in "control"'
+      )
       adapt_delta <- dots$adapt_delta
       dots$adapt_delta <- NULL
     } else {
       adapt_delta <- control$adapt_delta
-      if(is.null(adapt_delta)) adapt_delta  <- 0.8
+      if (is.null(adapt_delta)) adapt_delta <- 0.8
     }
 
-    if('max_treedepth' %in% names(dots)){
-      message('argument "max_treedepth" should be supplied as an element in "control"')
+    if ('max_treedepth' %in% names(dots)) {
+      message(
+        'argument "max_treedepth" should be supplied as an element in "control"'
+      )
       max_treedepth <- dots$max_treedepth
       dots$max_treedepth <- NULL
     } else {
       max_treedepth <- control$max_treedepth
-      if(is.null(max_treedepth)) max_treedepth  <- 10
+      if (is.null(max_treedepth)) max_treedepth <- 10
     }
 
-    out <- structure(list(call = mod$call,
-                          trend_call = factor_formula,
-                          family = mod$family,
-                          share_obs_params = mod$share_obs_params,
-                          trend_model = 'None',
-                          trend_map = trend_map,
-                          drift = FALSE,
-                          priors = mod$priors,
-                          model_output = out_gam_mod,
-                          model_file = model_file,
-                          model_data = if(return_model_data){
-                            model_data
-                          } else {
-                            trim_data
-                          },
-                          inits = NULL,
-                          monitor_pars = param,
-                          sp_names = mod$sp_names,
-                          trend_sp_names = mod$trend_sp_names,
-                          mgcv_model = ss_gam,
-                          trend_mgcv_model = trend_mgcv_model,
-                          ytimes = mod$ytimes,
-                          resids = mod_residuals,
-                          use_lv = TRUE,
-                          n_lv = n_lv,
-                          upper_bounds = mod$upper_bounds,
-                          obs_data = mod$obs_data,
-                          test_data = mod$test_data,
-                          fit_engine = 'stan',
-                          backend = backend,
-                          algorithm = algorithm,
-                          max_treedepth = max_treedepth,
-                          adapt_delta = adapt_delta),
-                     class = c('mvgam', 'jsdgam'))
+    out <- structure(
+      list(
+        call = mod$call,
+        trend_call = factor_formula,
+        family = mod$family,
+        share_obs_params = mod$share_obs_params,
+        trend_model = 'None',
+        trend_map = trend_map,
+        drift = FALSE,
+        priors = mod$priors,
+        model_output = out_gam_mod,
+        model_file = model_file,
+        model_data = if (return_model_data) {
+          model_data
+        } else {
+          trim_data
+        },
+        inits = NULL,
+        monitor_pars = param,
+        sp_names = mod$sp_names,
+        trend_sp_names = mod$trend_sp_names,
+        mgcv_model = ss_gam,
+        trend_mgcv_model = trend_mgcv_model,
+        ytimes = mod$ytimes,
+        resids = mod_residuals,
+        use_lv = TRUE,
+        n_lv = n_lv,
+        upper_bounds = mod$upper_bounds,
+        obs_data = mod$obs_data,
+        test_data = mod$test_data,
+        fit_engine = 'stan',
+        backend = backend,
+        algorithm = algorithm,
+        max_treedepth = max_treedepth,
+        adapt_delta = adapt_delta
+      ),
+      class = c('mvgam', 'jsdgam')
+    )
   }
 
   return(out)
@@ -672,38 +743,47 @@ jsdgam = function(formula,
 
 #' Prep trend for jsdgam
 #' @noRd
-prep_jsdgam_trend = function(data, unit, subgr){
-
+prep_jsdgam_trend = function(data, unit, subgr) {
   unit <- as_one_character(unit)
   subgr <- as_one_character(subgr)
-  validate_var_exists(data = data,
-                              variable = unit,
-                              type = 'num/int',
-                              name = 'data',
-                              trend_char = 'ZMVN')
-  validate_var_exists(data = data,
-                              variable = subgr,
-                              type = 'factor',
-                              name = 'data',
-                              trend_char = 'ZMVN')
-  out <- structure(list(trend_model = 'ZMVN',
-                        ma = FALSE,
-                        cor = TRUE,
-                        unit = unit,
-                        gr = "NA",
-                        subgr = subgr,
-                        label = NULL),
-                   class = 'mvgam_trend')
+  validate_var_exists(
+    data = data,
+    variable = unit,
+    type = 'num/int',
+    name = 'data',
+    trend_char = 'ZMVN'
+  )
+  validate_var_exists(
+    data = data,
+    variable = subgr,
+    type = 'factor',
+    name = 'data',
+    trend_char = 'ZMVN'
+  )
+  out <- structure(
+    list(
+      trend_model = 'ZMVN',
+      ma = FALSE,
+      cor = TRUE,
+      unit = unit,
+      gr = "NA",
+      subgr = subgr,
+      label = NULL
+    ),
+    class = 'mvgam_trend'
+  )
 }
 
 #' @noRd
-prep_jsdgam_trendmap = function(data, n_lv){
-  if(n_lv > nlevels(data$series)){
-    stop('Number of factors must be <= number of levels in species',
-         call. = FALSE)
+prep_jsdgam_trendmap = function(data, n_lv) {
+  if (n_lv > nlevels(data$series)) {
+    stop(
+      'Number of factors must be <= number of levels in species',
+      call. = FALSE
+    )
   }
-  data.frame(trend = rep(1:n_lv,
-                         nlevels(data$series))[1:nlevels(data$series)],
-             series = factor(levels(data$series),
-                             levels = levels(data$series)))
+  data.frame(
+    trend = rep(1:n_lv, nlevels(data$series))[1:nlevels(data$series)],
+    series = factor(levels(data$series), levels = levels(data$series))
+  )
 }
