@@ -52,26 +52,30 @@
 #'str(expectations)
 #'}
 #' @export
-posterior_epred.mvgam = function(object,
-                                 newdata,
-                                 data_test,
-                                 ndraws = NULL,
-                                 process_error = TRUE, ...){
-
-  if(missing(newdata) & missing(data_test)){
+posterior_epred.mvgam = function(
+  object,
+  newdata,
+  data_test,
+  ndraws = NULL,
+  process_error = TRUE,
+  ...
+) {
+  if (missing(newdata) & missing(data_test)) {
     out <- .mvgam_fitted(object, type = 'expected')
   } else {
-    out <- predict(object,
-                   newdata = newdata,
-                   data_test = data_test,
-                   process_error = process_error,
-                   type = 'expected',
-                   summary = FALSE)
+    out <- predict(
+      object,
+      newdata = newdata,
+      data_test = data_test,
+      process_error = process_error,
+      type = 'expected',
+      summary = FALSE
+    )
   }
 
-  if(!is.null(ndraws)){
+  if (!is.null(ndraws)) {
     validate_pos_integer(ndraws)
-    if(ndraws > NROW(out)){
+    if (ndraws > NROW(out)) {
     } else {
       idx <- sample(1:NROW(out), ndraws, replace = FALSE)
       out <- out[idx, ]
@@ -125,30 +129,33 @@ posterior_epred.mvgam = function(object,
 #'str(linpreds)
 #'}
 #' @export
-posterior_linpred.mvgam = function(object,
-                                   transform = FALSE,
-                                   newdata,
-                                   ndraws = NULL,
-                                   data_test,
-                                   process_error = TRUE,
-                                   ...){
-
-  if(transform){
+posterior_linpred.mvgam = function(
+  object,
+  transform = FALSE,
+  newdata,
+  ndraws = NULL,
+  data_test,
+  process_error = TRUE,
+  ...
+) {
+  if (transform) {
     type <- 'expected'
   } else {
     type <- 'link'
   }
 
-  out <- predict(object,
-                 newdata = newdata,
-                 data_test = data_test,
-                 process_error = process_error,
-                 type = type,
-                 summary = FALSE)
+  out <- predict(
+    object,
+    newdata = newdata,
+    data_test = data_test,
+    process_error = process_error,
+    type = type,
+    summary = FALSE
+  )
 
-  if(!is.null(ndraws)){
+  if (!is.null(ndraws)) {
     validate_pos_integer(ndraws)
-    if(ndraws > NROW(out)){
+    if (ndraws > NROW(out)) {
     } else {
       idx <- sample(1:NROW(out), ndraws, replace = FALSE)
       out <- out[idx, ]
@@ -206,22 +213,26 @@ posterior_linpred.mvgam = function(object,
 #'str(predictions)
 #'}
 #' @export
-posterior_predict.mvgam = function(object,
-                                   newdata,
-                                   data_test,
-                                   ndraws = NULL,
-                                   process_error = TRUE, ...){
+posterior_predict.mvgam = function(
+  object,
+  newdata,
+  data_test,
+  ndraws = NULL,
+  process_error = TRUE,
+  ...
+) {
+  out <- predict(
+    object,
+    newdata = newdata,
+    data_test = data_test,
+    process_error = process_error,
+    type = 'response',
+    summary = FALSE
+  )
 
-  out <- predict(object,
-                 newdata = newdata,
-                 data_test = data_test,
-                 process_error = process_error,
-                 type = 'response',
-                 summary = FALSE)
-
-  if(!is.null(ndraws)){
+  if (!is.null(ndraws)) {
     validate_pos_integer(ndraws)
-    if(ndraws > NROW(out)){
+    if (ndraws > NROW(out)) {
     } else {
       idx <- sample(1:NROW(out), ndraws, replace = FALSE)
       out <- out[idx, ]
@@ -288,29 +299,37 @@ rstantools::posterior_linpred
 #'str(expectations)
 #'}
 #' @export
-fitted.mvgam <- function(object, process_error = TRUE,
-                        scale = c("response", "linear"),
-                        summary = TRUE, robust = FALSE,
-                        probs = c(0.025, 0.975), ...) {
-
+fitted.mvgam <- function(
+  object,
+  process_error = TRUE,
+  scale = c("response", "linear"),
+  summary = TRUE,
+  robust = FALSE,
+  probs = c(0.025, 0.975),
+  ...
+) {
+  if (length(probs) != 2L) {
+    stop("argument 'probs' must be a vector of length 2", call. = FALSE)
+  }
   scale <- match.arg(scale)
-  type <- switch(scale, "response" = "expected",
-                  "linear" = "link")
+  type <- switch(scale, "response" = "expected", "linear" = "link")
   preds <- .mvgam_fitted(object = object, type = type)
 
   # Preserve original data ordering
-  data.frame(time = object$obs_data$index..time..index,
-             order = object$obs_data$index..orig..order,
-             series = object$obs_data$series) %>%
+  data.frame(
+    time = object$obs_data$index..time..index,
+    order = object$obs_data$index..orig..order,
+    series = object$obs_data$series
+  ) %>%
     dplyr::arrange(time, series) %>%
     dplyr::pull(order) -> orig_order
-  preds <- preds[ , order(orig_order)]
+  preds <- preds[, order(orig_order)]
 
-  if(summary){
+  if (summary) {
     Qupper <- apply(preds, 2, quantile, probs = max(probs), na.rm = TRUE)
     Qlower <- apply(preds, 2, quantile, probs = min(probs), na.rm = TRUE)
 
-    if(robust){
+    if (robust) {
       estimates <- apply(preds, 2, median, na.rm = TRUE)
       errors <- apply(abs(preds - estimates), 2, median, na.rm = TRUE)
     } else {
@@ -319,8 +338,12 @@ fitted.mvgam <- function(object, process_error = TRUE,
     }
 
     out <- cbind(estimates, errors, Qlower, Qupper)
-    colnames(out) <- c('Estimate', 'Est.Error', paste0('Q', 100*min(probs)),
-                       paste0('Q', 100*max(probs)))
+    colnames(out) <- c(
+      'Estimate',
+      'Est.Error',
+      paste0('Q', 100 * min(probs)),
+      paste0('Q', 100 * max(probs))
+    )
   } else {
     out <- preds
   }
@@ -329,76 +352,79 @@ fitted.mvgam <- function(object, process_error = TRUE,
 }
 
 #' @noRd
-.mvgam_fitted = function(object, type = 'expected'){
+.mvgam_fitted = function(object, type = 'expected') {
+  # Extract the linear predictor draws
+  mus <- mcmc_chains(object$model_output, 'mus')
 
-    # Extract the linear predictor draws
-    mus <- mcmc_chains(object$model_output, 'mus')
-
-    # Need to know which series each observation belongs to so we can
-    # pull out appropriate family-level parameters (overdispersions, shapes, etc...)
-    if(is.null(object$test_data)){
-      all_dat <- data.frame(series = object$obs_data$series,
-                            time = object$obs_data$time,
-                            y = object$obs_data$y) %>%
-        dplyr::arrange(series, time)
-    } else {
-      all_dat <- data.frame(series = c(object$obs_data$series,
-                                       object$test_data$series),
-                            time = c(object$obs_data$time,
-                                     object$test_data$time),
-                            y = c(object$obs_data$y,
-                                  object$test_data$y)) %>%
-        dplyr::arrange(series, time)
-    }
-
-    obs <- all_dat$y
-    series_obs <- as.numeric(all_dat$series)
-
-    # Family-specific parameters
-    family <- object$family
-    family_pars <- extract_family_pars(object = object)
-    n_series <- NCOL(object$ytimes)
-
-    # Family parameters spread into a vector
-    family_extracts <- lapply(seq_along(family_pars), function(j){
-      if(is.matrix(family_pars[[j]])){
-        as.vector(family_pars[[j]][, series_obs])
-      } else {
-        family_pars[[j]][]
-      }
-    })
-    names(family_extracts) <- names(family_pars)
-
-    # Add trial information if this is a Binomial model
-    if(object$family %in% c('binomial', 'beta_binomial')){
-      trials <- as.vector(matrix(rep(as.vector(attr(object$mgcv_model, 'trials')),
-                                     NROW(mus)),
-                                 nrow = NROW(mus),
-                                 byrow = TRUE))
-      family_extracts$trials <- trials
-    }
-
-    # Expectations as a vector
-    Xp <- as.matrix(as.vector(mus))
-    attr(Xp, 'model.offset') <- 0
-
-    if(family == 'nmix'){
-      latent_lambdas <- exp(as.vector(mcmc_chains(object$model_output, 'trend')))
-      n_draws <- dim(mcmc_chains(object$model_output, 'ypred'))[1]
-      cap <- as.vector(t(replicate(n_draws, object$obs_data$cap)))
-    } else {
-      latent_lambdas <- NULL
-      cap <- NULL
-    }
-    pred_vec <- mvgam_predict(family = family,
-                              family_pars = family_extracts,
-                              latent_lambdas = latent_lambdas,
-                              cap = cap,
-                              type = type,
-                              Xp = Xp,
-                              betas = 1)
-
-    # Convert back to matrix and return
-    pred_mat <- matrix(pred_vec, nrow = NROW(mus))
-    return(pred_mat)
+  # Need to know which series each observation belongs to so we can
+  # pull out appropriate family-level parameters (overdispersions, shapes, etc...)
+  if (is.null(object$test_data)) {
+    all_dat <- data.frame(
+      series = object$obs_data$series,
+      time = object$obs_data$time,
+      y = object$obs_data$y
+    ) %>%
+      dplyr::arrange(series, time)
+  } else {
+    all_dat <- data.frame(
+      series = c(object$obs_data$series, object$test_data$series),
+      time = c(object$obs_data$time, object$test_data$time),
+      y = c(object$obs_data$y, object$test_data$y)
+    ) %>%
+      dplyr::arrange(series, time)
   }
+
+  obs <- all_dat$y
+  series_obs <- as.numeric(all_dat$series)
+
+  # Family-specific parameters
+  family <- object$family
+  family_pars <- extract_family_pars(object = object)
+  n_series <- NCOL(object$ytimes)
+
+  # Family parameters spread into a vector
+  family_extracts <- lapply(seq_along(family_pars), function(j) {
+    if (is.matrix(family_pars[[j]])) {
+      as.vector(family_pars[[j]][, series_obs])
+    } else {
+      family_pars[[j]][]
+    }
+  })
+  names(family_extracts) <- names(family_pars)
+
+  # Add trial information if this is a Binomial model
+  if (object$family %in% c('binomial', 'beta_binomial')) {
+    trials <- as.vector(matrix(
+      rep(as.vector(attr(object$mgcv_model, 'trials')), NROW(mus)),
+      nrow = NROW(mus),
+      byrow = TRUE
+    ))
+    family_extracts$trials <- trials
+  }
+
+  # Expectations as a vector
+  Xp <- as.matrix(as.vector(mus))
+  attr(Xp, 'model.offset') <- 0
+
+  if (family == 'nmix') {
+    latent_lambdas <- exp(as.vector(mcmc_chains(object$model_output, 'trend')))
+    n_draws <- dim(mcmc_chains(object$model_output, 'ypred'))[1]
+    cap <- as.vector(t(replicate(n_draws, object$obs_data$cap)))
+  } else {
+    latent_lambdas <- NULL
+    cap <- NULL
+  }
+  pred_vec <- mvgam_predict(
+    family = family,
+    family_pars = family_extracts,
+    latent_lambdas = latent_lambdas,
+    cap = cap,
+    type = type,
+    Xp = Xp,
+    betas = 1
+  )
+
+  # Convert back to matrix and return
+  pred_mat <- matrix(pred_vec, nrow = NROW(mus))
+  return(pred_mat)
+}
